---
name: Feature request
about: Suggest an idea for this project
title: ''
labels: enhancement
assignees: ''

---

## Purpuse of the feature request

A description of feature purpose, specifications, and user experience changes.

## Describe the solution you'd like

A clear and concise description of what you want to happen.

## Additional context

Add any other context or screenshots about the feature request here.
